unit Order;

interface

uses classes, Sysutils;

type

  TOrder = class(TObject)
    constructor Create(ConfigStrings: TStrings);
    function GetImageNumber: Integer;
    function GetDisplayDuration: Integer;
    function IsStartOfList: Boolean;
    procedure NextImage;
  private
    CurrentPosition: Integer;
    ImageNumberArray: array of Integer;
    DisplayDurationArray: array of Integer;
    function SplitString(const InputString: String; const SplitChar: Char; PartNumber: Integer): String;
  end;


implementation

constructor TOrder.Create(ConfigStrings: TStrings);
var
    AddedImages: Integer;
    Counter: Integer;
    CurrentString: String;
    TempString: String;
    TempInt: Integer;
begin
     AddedImages := 0;

     SetLength(ImageNumberArray, ConfigStrings.Count);
     SetLength(DisplayDurationArray, ConfigStrings.Count);

     for Counter := 0 to ConfigStrings.Count -1 do
     begin
         CurrentString := ConfigStrings.Strings[Counter];
         TempString := Trim(SplitString(CurrentString, ',', 1));
         try
             TempInt := StrToInt(TempString);
             ImageNumberArray[AddedImages] := TempInt;

             TempString := Trim(SplitString(CurrentString, ',', 2));
             TempInt := StrToInt(TempString);
             DisplayDurationArray[AddedImages] := TempInt;

             AddedImages := AddedImages + 1;
         except
             //Skip over this one...
         end;
     end;

     SetLength(ImageNumberArray, AddedImages - 1);
     SetLength(DisplayDurationArray, AddedImages - 1);

     CurrentPosition := 0;
end;


function TOrder.GetImageNumber: Integer;
begin
    result := ImageNumberArray[CurrentPosition];
end;


function TOrder.GetDisplayDuration: Integer;
begin
     result := DisplayDurationArray[CurrentPosition];
end;


procedure TOrder.NextImage;
begin
    CurrentPosition := CurrentPosition + 1;

    if CurrentPosition >= Length(ImageNumberArray) then
    begin
         CurrentPosition := 0;
    end
end;


function TOrder.IsStartOfList: Boolean;
begin
    result := CurrentPosition = 0;
end;


function TOrder.SplitString(const InputString: String; const SplitChar: Char; PartNumber: Integer): String;
var
     CharacterNumber, CurrentPartNo: integer;
begin
     CurrentPartNo := 1;
     result := '';
     
     for CharacterNumber := 1 to length(InputString) do
     begin
         if (InputString[CharacterNumber] = SplitChar) then
         begin
             if CurrentPartNo = PartNumber then
             begin
                 exit;
             end
             else
             begin
                 CurrentPartNo := CurrentPartNo + 1;
                 result := '';
             end;
         end
         else
         begin
             result := result + InputString[CharacterNumber];
         end;
     end;
end;

end.
